==> gmic_2.4.0.tar.gz: gmic-2.4.0/gmic-qt/src/Widgets/ZoomLevelSelector.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file ZoomLevelSelector.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef _GMIC_QT_ZOOMLEVELSELECTOR_H
#define _GMIC_QT_ZOOMLEVELSELECTOR_H

#include <QDoubleValidator>
#include <QPalette>
#include <QWidget>
#include "ZoomConstraint.h"

namespace Ui
{
class ZoomLevelSelector;
}

class PreviewWidget;

class ZoomLevelSelector : public QWidget {
  Q_OBJECT

public:
  explicit ZoomLevelSelector(QWidget * parent = 0);
  ~ZoomLevelSelector();

  void setZoomConstraint(ZoomConstraint constraint);

  void setPreviewWidget(const PreviewWidget *);

public slots:
  void display(const double zoom);
  void showWarning(bool on);

private slots:
  void onComboBoxEditingFinished();
  void onComboIndexChanged(int);

signals:
  void valueChanged(double);
  void zoomIn();
  void zoomOut();
  void zoomReset();

private:
  Ui::ZoomLevelSelector * ui;
  bool _notificationsEnabled;
  double currentZoomValue();
  QString _currentText;
  ZoomConstraint _zoomConstraint;
  const PreviewWidget * _previewWidget;
};

class ZoomLevelValidator : public QValidator {

public:
  ZoomLevelValidator(QObject * parent);
  QValidator::State validate(QString & input, int & pos) const override;

private:
  QDoubleValidator * _doubleValidator;
};

#endif // _GMIC_QT_ZOOMLEVELSELECTOR_H

==> gmic_2.9.8.tar.gz: gmic-2.9.8/gmic-qt/src/Widgets/ZoomLevelSelector.h <==
/** -*- mode: c++ ; c-basic-offset: 2 -*-
 *
 *  @file ZoomLevelSelector.h
 *
 *  Copyright 2017 Sebastien Fourey
 *
 *  This file is part of G'MIC-Qt, a generic plug-in for raster graphics
 *  editors, offering hundreds of filters thanks to the underlying G'MIC
 *  image processing framework.
 *
 *  gmic_qt is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  gmic_qt is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with gmic_qt.  If not, see <http://www.gnu.org/licenses/>.
 *
 */
#ifndef GMIC_QT_ZOOMLEVELSELECTOR_H
#define GMIC_QT_ZOOMLEVELSELECTOR_H

#include <QDoubleValidator>
#include <QPalette>
#include <QWidget>
#include "ZoomConstraint.h"
namespace Ui
{
class ZoomLevelSelector;
}

namespace GmicQt
{

class PreviewWidget;

class ZoomLevelSelector : public QWidget {
  Q_OBJECT

public:
  explicit ZoomLevelSelector(QWidget * parent = nullptr);
  ~ZoomLevelSelector();

  void setZoomConstraint(const ZoomConstraint & constraint);

  void setPreviewWidget(const PreviewWidget *);

public slots:
  void display(const double zoom);
  void showWarning(bool on);

private slots:
  void onComboBoxEditingFinished();
  void onComboIndexChanged(int);

signals:
  void valueChanged(double);
  void zoomIn();
  void zoomOut();
  void zoomReset();

private:
  Ui::ZoomLevelSelector * ui;
  bool _notificationsEnabled;
  double currentZoomValue();
  QString _currentText;
  ZoomConstraint _zoomConstraint;
  const PreviewWidget * _previewWidget;
};

class ZoomLevelValidator : public QValidator {

public:
  ZoomLevelValidator(QObject * parent);
  QValidator::State validate(QString & input, int & pos) const override;

private:
  QDoubleValidator * _doubleValidator;
};

} // namespace GmicQt

#endif // GMIC_QT_ZOOMLEVELSELECTOR_H
